@@ -1,7 +1,7 @@
 # SPDX-FileCopyrightText: 2017-2021 Alliander N.V. <korte.termijn.prognoses@alliander.com> # noqa E501>
 #
 # SPDX-License-Identifier: MPL-2.0
-from enum import Enum, auto
+from enum import Enum
 
 
 # TODO replace this with ModelType (MLModelType == Machine Learning model type)
