@@ -4,6 +4,7 @@
 from datetime import datetime
 import pytz
 from typing import List
+import structlog
 
 import numpy as np
 import pandas as pd
@@ -17,6 +18,7 @@ class ConfidenceIntervalApplicator:
     def __init__(self, model: RegressorMixin, forecast_input_data: pd.DataFrame):
         self.model = model
         self.forecast_input_data = forecast_input_data
+        self.logger = structlog.get_logger(self.__class__.__name__)
 
     def add_confidence_interval(
         self,
@@ -89,25 +91,23 @@ class ConfidenceIntervalApplicator:
         if standard_deviation is None:
             return forecast
 
+        # Fill stdev nans with the mean of all stdev values
+        if standard_deviation.stdev.isnull().values.any():
+            self.logger.warning(
+                "Stdev for some hours is not known, filling in with mean."
+            )
+            standard_deviation["stdev"] = standard_deviation.stdev.fillna(
+                standard_deviation.stdev.mean()
+            )
+
         # -------- Moved from feature_engineering.add_stdev ------------------------- #
-        # pivot
+        # pivot. idea is to have a dataframe with columns [stdev, hour, horizon] for a 'near' and a 'far' horizon
         stdev = standard_deviation.pivot_table(columns=["horizon"], index="hour")[
             "stdev"
         ]
-        # Prepare input dataframes
-        # Rename Near and Far to 0.25 and 47 respectively, if present.
-        # Timehorizon in hours is preferred to less descriptive Near/Far
-        if "Near" in stdev.columns:
-            near = (forecast.index[1] - forecast.index[0]).total_seconds() / 3600.0
-            # Try to infer for forecast df, else use a max of 48 hours
-            far = min(
-                48.0,
-                (forecast.index.max() - forecast.index.min()).total_seconds() / 3600.0,
-            )
-            stdev.rename(columns={"Near": near, "Far": far}, inplace=True)
-        else:
-            near = stdev.columns.min()
-            far = stdev.columns.max()
+        # Prepare input dataframes for near and far horizon
+        near = stdev.columns.min()
+        far = stdev.columns.max()
 
         forecast_copy = forecast.copy()
         # add time ahead column if not already present
@@ -115,16 +115,16 @@ class ConfidenceIntervalApplicator:
             # Determine now, rounded on 15 minutes,
             # Rounding helps to prevent fractional t_aheads
             now = (
-                pd.Series(datetime.utcnow().replace(tzinfo=pytz.utc))
+                pd.Series(datetime.utcnow().replace(tzinfo=forecast_copy.index.tzinfo))
                 .min()
                 .round(f"{MINIMAL_RESOLUTION}T")
                 .to_pydatetime()
             )
-
             # Determin t_aheads by subtracting with now
             forecast_copy["tAhead"] = (
                 forecast_copy.index - now
             ).total_seconds() / 3600.0
+
         # add helper column hour
         forecast_copy["hour"] = forecast_copy.index.hour
 
