@@ -4,8 +4,8 @@
 from pathlib import Path
 
 import pymsteams
-from ktpbase.config.config import ConfigManager
-from ktpbase.log import logging
+from openstf_dbc.config.config import ConfigManager
+import structlog
 
 
 def post_teams(msg, invalid_coefs=None, coefsdf=None, url=None):
@@ -29,10 +29,45 @@ def post_teams(msg, invalid_coefs=None, coefsdf=None, url=None):
 
     Note:
         This function is namespace-specific.
-
     """
     config = ConfigManager.get_instance()
-    logger = logging.get_logger(__name__)
+    logger = structlog.get_logger(__name__)
+
+    # Add invalid coefficients and manual coefficients-query to message
+    if invalid_coefs is not None and coefsdf is not None:
+        # add invalid coefficient information to message in dict-format
+        invalid_coefs_text = "".join(
+            [
+                f"\n* **{row.coef_name}**: {round(row.coef_value_new, 2)}, "
+                f"(previous: {round(row.coef_value_last, 2)})"
+                for index, row in invalid_coefs.iterrows()
+            ]
+        )
+        query = build_sql_query_string(coefsdf, "energy_split_coefs")
+        query_text = (
+            "If you would like to update the coefficients manually in the "
+            + "database, use this query:"
+        )
+        msg = {
+            "fallback": msg,
+            "title": "Invalid energy splitting coefficients",
+            "text": msg,
+            "sections": [
+                {
+                    "text": invalid_coefs_text,
+                    "markdown": True,
+                },
+                {
+                    "title": "Manual query",
+                    "text": query_text,
+                    "markdown": True,
+                },
+                {
+                    "text": query,
+                    "markdown": True,
+                },
+            ],
+        }
 
     # If no url is passed fall back to default
     if url is None:
@@ -290,3 +325,29 @@ def send_report_teams_worse(pj):
     }
 
     post_teams(msg)
+
+
+def format_message(title, params, fallback=None, color=None):
+    if color is None:
+        color = "#046b00"  # green
+    if fallback is None:
+        fallback = title
+
+    # format allparams using limited precision for floats
+    # make keys bold (**key**)
+    values = []
+    for k, v in params.items():
+        if type(v) is float:
+            values.append(f"**{k}**: {v:0.3f}")
+            continue
+        values.append(f"**{k}**: {v}")
+    # join all {params}: {value}  pairs with a new line
+    text = "".join([f"* {v}   \n" for v in values])
+
+    msg = {
+        "fallback": fallback,
+        "title": title,
+        "text": text,
+        "color": color,
+    }
+    return msg
