@@ -3,21 +3,25 @@
 # SPDX-License-Identifier: MPL-2.0
 
 from datetime import datetime, timedelta
+from pathlib import Path
 
 from openstf.model.capacity.predict import predict_capacity_prognosis
 from openstf.tasks.utils.predictionjobloop import PredictionJobLoop
 from openstf.tasks.utils.taskcontext import TaskContext
+from openstf.enums import MLModelType
 
 
 def main():
-    with TaskContext("create_capacity_forecast") as context:
+    taskname = Path(__file__).name.replace(".py", "")
+
+    with TaskContext(taskname) as context:
         # prediction horizons
         y_hor = list(range(13))
 
         # define input range
         datetime_start = datetime.utcnow().date() - timedelta(days=30)
         datetime_end = datetime.utcnow().date() + timedelta(days=max(y_hor) + 1)
-        model_type = ["xgb", "lgb"]
+        model_type = [ml.value for ml in MLModelType]
 
         PredictionJobLoop(context, model_type=model_type).map(
             predict_capacity_prognosis,
