@@ -28,11 +28,13 @@ Attributes:
 
 """
 from datetime import datetime, timedelta
+from pathlib import Path
 
 from openstf.pipeline.create_forecast import create_forecast_pipeline
 from openstf.tasks.utils.utils import check_status_change, update_status_change
 from openstf.tasks.utils.predictionjobloop import PredictionJobLoop
 from openstf.tasks.utils.taskcontext import TaskContext
+from openstf.enums import MLModelType
 
 T_BEHIND_DAYS: int = 14
 T_AHEAD_DAYS: int = 3
@@ -43,6 +45,9 @@ def create_forecast_task(pj: dict, context: TaskContext) -> None:
 
     On this task level all database and context manager dependencies are resolved.
 
+    Expected prediction job keys: "id", "lat", "lon", "resolution_minutes",
+        "horizon_minutes", "type", "name", "model_type_group", "quantiles"
+
     Args:
         pj (dict): Prediction job
         context (TaskContext): Contect object that holds a config manager and a database connection
@@ -69,10 +74,14 @@ def create_forecast_task(pj: dict, context: TaskContext) -> None:
     context.database.write_forecast(forecast, t_ahead_series=True)
 
 
-def main():
-    with TaskContext("create_forecast") as context:
-        model_type = ["xgb", "xgb_quantile", "lgb"]
+def main(model_type=None):
 
+    if model_type is None:
+        model_type = [ml.value for ml in MLModelType]
+
+    taskname = Path(__file__).name.replace(".py", "")
+
+    with TaskContext(taskname) as context:
         # status file callback after every iteration
         # TODO change implementation to a database one
         def callback(pj, successful):
