@@ -17,36 +17,52 @@ Example:
 
 """
 from datetime import datetime, timedelta
+from pathlib import Path
 
 from openstf.pipeline.optimize_hyperparameters import optimize_hyperparameters_pipeline
 from openstf.tasks.utils.predictionjobloop import PredictionJobLoop
 from openstf.tasks.utils.taskcontext import TaskContext
 from openstf.monitoring import teams
+from openstf.enums import MLModelType
 
 MAX_AGE_HYPER_PARAMS_DAYS = 31
+DEFAULT_TRAINING_PERIOD_DAYS = 91
 
 
 def optimize_hyperparameters_task(pj: dict, context: TaskContext) -> None:
+    """Optimize hyperparameters task.
+
+    Expected prediction job keys: "id", "model", "lat", "lon", "name", "description"
+    Only used for logging: "name", "description"
+
+    Args:
+        pj (dict): Prediction job
+        context (TaskContext): Task context
+    """
 
     # Determine if we need to optimize hyperparams
     datetime_last_optimized = context.database.get_hyper_params_last_optimized(pj)
-    last_optimized_days = (datetime.utcnow() - datetime_last_optimized).days
+    if datetime_last_optimized is not None:
+        last_optimized_days = (datetime.utcnow() - datetime_last_optimized).days
+        if last_optimized_days < MAX_AGE_HYPER_PARAMS_DAYS:
+            context.logger.warning(
+                "Skip hyperparameter optimization",
+                pid=pj["id"],
+                last_optimized_days=last_optimized_days,
+                max_age=MAX_AGE_HYPER_PARAMS_DAYS,
+            )
+            return
 
-    if last_optimized_days < MAX_AGE_HYPER_PARAMS_DAYS:
-        context.logger.warning(
-            "Skip hyperparameter optimization",
-            pid=pj["id"],
-            last_optimized_days=last_optimized_days,
-            max_age=MAX_AGE_HYPER_PARAMS_DAYS,
-        )
-        return
-
-    # Get input data
+    # Get input data (usese "id" and "model")
     current_hyperparams = context.database.get_hyper_params(pj)
-    # TODO this conversion should be done in the database
-    training_period_days = int(current_hyperparams["training_period_days"])
 
-    datetime_start = datetime.utcnow() - timedelta(days=training_period_days)
+    datetime_start = datetime.utcnow() - timedelta(
+        days=int(
+            current_hyperparams.get(
+                "training_period_days", DEFAULT_TRAINING_PERIOD_DAYS
+            )
+        )
+    )
     datetime_end = datetime.utcnow()
 
     input_data = context.database.get_model_input(
@@ -70,8 +86,10 @@ def optimize_hyperparameters_task(pj: dict, context: TaskContext) -> None:
 
 
 def main():
-    with TaskContext("optimize_hyperparameters") as context:
-        model_type = ["xgb", "xgb_quantile", "lgb"]
+    taskname = Path(__file__).name.replace(".py", "")
+
+    with TaskContext(taskname) as context:
+        model_type = [ml.value for ml in MLModelType]
 
         PredictionJobLoop(context, model_type=model_type).map(
             optimize_hyperparameters_task, context
