@@ -21,12 +21,13 @@ MINIMAL_TABLE_LENGTH = 100
 FLATLINER_TRESHOLD = 24
 
 
-def validate(data: pd.DataFrame) -> pd.DataFrame:
+def validate(
+    data: pd.DataFrame, flatliner_threshold: int = FLATLINER_TRESHOLD
+) -> pd.DataFrame:
     logger = structlog.get_logger(__name__)
     # Drop 'false' measurements. e.g. where load appears to be constant.
-    threshold = 6 * 4  # number of repeated values
     data = replace_repeated_values_with_nan(
-        data, max_length=threshold, column_name=data.columns[0]
+        data, max_length=flatliner_threshold, column_name=data.columns[0]
     )
     num_const_load_values = len(data) - len(data.iloc[:, 0].dropna())
     logger.debug(
@@ -35,7 +36,7 @@ def validate(data: pd.DataFrame) -> pd.DataFrame:
     )
 
     # Check for repeated load observations due to invalid measurements
-    suspicious_moments = find_nonzero_flatliner(data, threshold=FLATLINER_TRESHOLD)
+    suspicious_moments = find_nonzero_flatliner(data, threshold=flatliner_threshold)
     if suspicious_moments is not None:
         # Covert repeated load observations to NaN values
         data = replace_invalid_data(data, suspicious_moments)
